==> haskell-sqlite-simple-0.4.19.0-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sqlite-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sqlite-simple
version:              0.4.19.0
visibility:           public
id:                   sqlite-simple-0.4.19.0-IB5bNn2tRlk6oJWamoLSh4
key:                  sqlite-simple-0.4.19.0-IB5bNn2tRlk6oJWamoLSh4
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.,
    (c) 2011-2012 Leon P Smith,
    (c) 2012-2014 Janne Hellsten

maintainer:           Janne Hellsten <jjhellst@gmail.com>
author:               Bryan O'\''Sullivan, Leon P Smith, Janne Hellsten
stability:            stable
homepage:             http://github.com/nurpax/sqlite-simple
synopsis:             Mid-Level SQLite client library
description:
    Mid-level SQLite client library, based on postgresql-simple.

    Main documentation (with examples): <docs/Database-SQLite-Simple.html Database.SQLite.Simple>

    You can view the project page at <http://github.com/nurpax/sqlite-simple>
    for more information.

category:             Database
abi:                  da6b04aff4727b970651a4928d3089b0
exposed:              True
exposed-modules:
    Database.SQLite.Simple Database.SQLite.Simple.FromField
    Database.SQLite.Simple.FromRow Database.SQLite.Simple.Function
    Database.SQLite.Simple.Internal Database.SQLite.Simple.Ok
    Database.SQLite.Simple.QQ Database.SQLite.Simple.Time
    Database.SQLite.Simple.Time.Implementation
    Database.SQLite.Simple.ToField Database.SQLite.Simple.ToRow
    Database.SQLite.Simple.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/sqlite-simple-0.4.19.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sqlite-simple-0.4.19.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sqlite-simple-0.4.19.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sqlite-simple
hs-libraries:         HSsqlite-simple-0.4.19.0-IB5bNn2tRlk6oJWamoLSh4
depends:
    Only-0.1-2ALIOaFTuVl17VyQ33BnR1
    attoparsec-0.14.4-x6mFqXglGqIZ8dJ9fSoCx base-4.17.2.1
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS
    blaze-textual-0.2.3.1-9f7evhhY42J5jaxfMsIsNN bytestring-0.11.5.3
    containers-0.6.7 direct-sqlite-2.3.29-8WmeZVG10viHga0vx7yGjr
    exceptions-0.10.5 template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-sqlite-simple/html/sqlite-simple.haddock

haddock-html:         /usr/share/doc/haskell-sqlite-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sqlite-simple-0.4.19.0-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sqlite-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sqlite-simple
version:              0.4.19.0
visibility:           public
id:                   sqlite-simple-0.4.19.0-4YGq6VZCG3vKHuiyXlxbeh
key:                  sqlite-simple-0.4.19.0-4YGq6VZCG3vKHuiyXlxbeh
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.,
    (c) 2011-2012 Leon P Smith,
    (c) 2012-2014 Janne Hellsten

maintainer:           Janne Hellsten <jjhellst@gmail.com>
author:               Bryan O'\''Sullivan, Leon P Smith, Janne Hellsten
stability:            stable
homepage:             http://github.com/nurpax/sqlite-simple
synopsis:             Mid-Level SQLite client library
description:
    Mid-level SQLite client library, based on postgresql-simple.

    Main documentation (with examples): <docs/Database-SQLite-Simple.html Database.SQLite.Simple>

    You can view the project page at <http://github.com/nurpax/sqlite-simple>
    for more information.

category:             Database
abi:                  48dae385baf2bf4dbfc0a457dead0418
exposed:              True
exposed-modules:
    Database.SQLite.Simple Database.SQLite.Simple.FromField
    Database.SQLite.Simple.FromRow Database.SQLite.Simple.Function
    Database.SQLite.Simple.Internal Database.SQLite.Simple.Ok
    Database.SQLite.Simple.QQ Database.SQLite.Simple.Time
    Database.SQLite.Simple.Time.Implementation
    Database.SQLite.Simple.ToField Database.SQLite.Simple.ToRow
    Database.SQLite.Simple.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/sqlite-simple-0.4.19.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sqlite-simple-0.4.19.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sqlite-simple-0.4.19.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sqlite-simple
hs-libraries:         HSsqlite-simple-0.4.19.0-4YGq6VZCG3vKHuiyXlxbeh
depends:
    Only-0.1-2ALIOaFTuVl17VyQ33BnR1
    attoparsec-0.14.4-GkPzleiGSjl3NaBuhMDecM base-4.17.2.1
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS
    blaze-textual-0.2.3.1-7lkGaYGePPf1OQsRQA8uHG bytestring-0.11.5.3
    containers-0.6.7 direct-sqlite-2.3.29-KcHbF8fLKE5Khb8LZBCtOc
    exceptions-0.10.5 template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-sqlite-simple/html/sqlite-simple.haddock

haddock-html:         /usr/share/doc/haskell-sqlite-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
